.widget-fatlist span.label {
    float: left;
    font-size: 110%;
    padding-right: 2pt;
    text-align: right;
    width: 46%;
}

.widget-fatlist span.label.fat, .widget-fatlist span.value.fat {
    width: 52%;
}

.widget-fatlist span.label::after {
    content: " \2022"
}

.widget-fatlist span.value {
    color: #fff;
    float: left;
    font-size: 110%;
    padding-left: 2pt;
    padding-right 2pt;
    width: 46%;
}
