.widget-commitlist { 
    background-color: #860000;
}

.widget-commitlist .title { 
    color: rgba(255, 255, 255, 0.7);
}

.widget-commitlist ol, ul {
    margin: 0 15px;
    text-align: left;
}

.widget-commitlist ol {
    list-style-position: inside;
}

.widget-commitlist li {
    font-size: 12px;
    border-top: 1px solid #FF0000;
    background-color: #860000;
    padding-top: 6px;
    margin-bottom: 6px;
}

.widget-commitlist .commitlist-nostyle {
    list-style: none;
}

.widget-commitlist .author {
    float: right;
    color: rgba(255, 255, 255, 0.3);
    font-weight: 600;
}

.widget-commitlist a .sha {
    float: left;
    text-transform: uppercase;
    color: rgba(255, 0, 0, 0.7);
    font-weight: 900;
}

.widget-commitlist .message {
    padding-top:2px;
    width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    color: rgba(255, 255, 255, 0.7) !important;
}
