.widget-assignment {
    background-color: #96bf48;
}

.widget-assignment h1 {
    color: rgba(255, 255, 255, 0.7);
}

.widget-assignment h2 {
    color: #fff;
}

.widget-assignment .until {
    font-size: 15pt;
    margin-top: 5pt;
}

.widget-assignment .until::before {
    content: 'Until ';
}

.widget-assignment .updated-at {
    color: rgba(0, 0, 0, 0.3);
}
