.widget-informednumber {
    background-color: #400000;
    text-align: center;
}

.widget-informednumber .title {
    color: rgba(255, 255, 255, 0.7);
    font-size: 30px;
    font-weight: 400;
    margin-bottom: 12px;
    padding-top: 12px;
}

.widget-informednumber .value {
    color: #fff;
    font-family: sans-serif;
    font-size: 120pt;
    font-weight: 900;
    letter-spacing: -10px;
    margin-top: -25pt;
}


.widget-informednumber .extra-column {
    padding-right: 10pt;
    width: 40%;
}

.widget-informednumber .extra-row {
    border: 1px solid rgba(255, 255, 255, 0.3);
}

.widget-informednumber .extra-label {
    text-transform: uppercase;
    color: rgba(255, 255, 255, 0.7);
    font-size: 10pt;
    text-align: right;
}

.widget-informednumber .extra-value {
    padding-left: 5pt;
    color: rgba(255, 255, 255, 0.7);
    font-size: 15pt;
    text-align: center;
}

.widget-informednumber .updated-at {
    color: rgba(0, 0, 0, 0.3);
}
